@echo off

REM  Calling verify with no args just checks the verify flag,
REM   we use this for its side effect of setting errorlevel to zero
verify >nul

REM  Attempt to read a particular system directory - the DIR
REM   command will fail with a nonzero errorlevel if the directory is
REM   unreadable by the current process.  The DACL on the
REM   c:\windows\system32\config\systemprofile directory, by default,
REM   only permits SYSTEM and Administrators.
dir %windir%\system32\config\systemprofile >nul 2>nul

REM  Use IF ERRORLEVEL or %errorlevel% to check the result
if not errorlevel 1 echo Has Admin Permissions, continuing!
if     errorlevel 1 EXIT /B 1

REM Set current directory as working directory so we can use relative paths
pushd %~dp0

REM Delete any pre-existing install
del /q apathy 2>null
del /q legalism 2>null
del /q newage 2>null
del /q heart 2>null
del /q title 2>null
del /q *.wdl 2>null
del /q *.wmp 2>null

REM Create extraction directories
mkdir apathy
mkdir legalism
mkdir newage
mkdir heart
mkdir title

REM Patch up game assets to retail 1.3 version
bspatch.exe RETAIL\Apathy.wrs RETAIL\apathy.wrs patches/1.0a/apathy-wrs.patch
bspatch.exe RETAIL\Legalism.wrs RETAIL\LEGALISM.wrs patches/1.0a/legalism-wrs.patch
bspatch.exe RETAIL\Newage.wrs RETAIL\NEWAGE.wrs patches/1.0a/newage-wrs.patch
bspatch.exe RETAIL\Heart.wrs RETAIL\HEART.wrs patches/1.0a/heart-wrs.patch
bspatch.exe RETAIL\Title.wrs RETAIL\TITLE.wrs patches/1.0a/title-wrs.patch
bspatch.exe RETAIL\Vrun.exe RETAIL\Vrun.exe patches/vrun-exe.patch

REM Use QuickBMS to extract the retail assets
quickbms.exe extract-wrs.bms RETAIL\apathy.wrs apathy
quickbms.exe extract-wrs.bms RETAIL\LEGALISM.wrs legalism
quickbms.exe extract-wrs.bms RETAIL\NEWAGE.wrs newage
quickbms.exe extract-wrs.bms RETAIL\HEART.wrs heart
quickbms.exe extract-wrs.bms RETAIL\TITLE.wrs title

REM Apply SaintsX patches to WDL files
patch.exe ./apathy/APATHY.WDL ./patches/apathy/apathy-wdl.patch
patch.exe ./legalism/LEGALISM.WDL ./patches/legalism/legalism-wdl.patch
patch.exe ./newage/NEWAGE.WDL ./patches/newage/newage-wdl.patch
patch.exe ./heart/HEART.WDL ./patches/heart/heart-wdl.patch
patch.exe ./title/TITLE.WDL ./patches/title/title-wdl.patch
patch.exe ./apathy/allobj.wdl ./patches/apathy/allobj-wdl.patch
patch.exe ./apathy/apathsnd.wdl ./patches/apathy/apathsnd-wdl.patch
patch.exe ./apathy/common.wdl ./patches/apathy/common-wdl.patch
patch.exe ./apathy/dead.wdl ./patches/apathy/dead-wdl.patch
patch.exe ./apathy/debug.wdl ./patches/apathy/debug-wdl.patch
patch.exe ./apathy/despair.wdl ./patches/apathy/despair-wdl.patch
patch.exe ./apathy/doors.wdl ./patches/apathy/doors-wdl.patch
patch.exe ./apathy/enemies1.wdl ./patches/apathy/enemies1-wdl.patch
patch.exe ./apathy/gallery.wdl ./patches/apathy/gallery-wdl.patch
patch.exe ./apathy/globals.wdl ./patches/apathy/globals-wdl.patch
patch.exe ./apathy/lonely.wdl ./patches/apathy/lonely-wdl.patch
patch.exe ./apathy/mall.wdl ./patches/apathy/mall-wdl.patch
patch.exe ./apathy/media.wdl ./patches/apathy/media-wdl.patch
patch.exe ./apathy/menu.wdl ./patches/apathy/menu-wdl.patch
patch.exe ./apathy/move.wdl ./patches/apathy/move-wdl.patch
patch.exe ./apathy/multi.wdl ./patches/apathy/multi-wdl.patch
patch.exe ./apathy/objects.wdl ./patches/apathy/objects-wdl.patch
patch.exe ./apathy/prayer.wdl ./patches/apathy/prayer-wdl.patch
patch.exe ./apathy/scroll.wdl ./patches/apathy/scroll-wdl.patch
patch.exe ./apathy/sounds.wdl ./patches/apathy/sounds-wdl.patch
patch.exe ./apathy/statue.wdl ./patches/apathy/statue-wdl.patch
patch.exe ./apathy/weapon.wdl ./patches/apathy/weapon-wdl.patch
patch.exe ./heart/allobj.wdl ./patches/heart/allobj-wdl.patch
patch.exe ./heart/common.wdl ./patches/heart/common-wdl.patch
patch.exe ./heart/dead.wdl ./patches/heart/dead-wdl.patch
patch.exe ./heart/debug.wdl ./patches/heart/debug-wdl.patch
patch.exe ./heart/doors.wdl ./patches/heart/doors-wdl.patch
patch.exe ./heart/enemies1.wdl ./patches/heart/enemies1-wdl.patch
patch.exe ./heart/enemies2.wdl ./patches/heart/enemies2-wdl.patch
patch.exe ./heart/enemies3.wdl ./patches/heart/enemies3-wdl.patch
patch.exe ./heart/globals.wdl ./patches/heart/globals-wdl.patch
patch.exe ./heart/heartsnd.wdl ./patches/heart/heartsnd-wdl.patch
patch.exe ./heart/menu.wdl ./patches/heart/menu-wdl.patch
patch.exe ./heart/move.wdl ./patches/heart/move-wdl.patch
patch.exe ./heart/objects.wdl ./patches/heart/objects-wdl.patch
patch.exe ./heart/prayer.wdl ./patches/heart/prayer-wdl.patch
patch.exe ./heart/scroll.wdl ./patches/heart/scroll-wdl.patch
patch.exe ./heart/sounds.wdl ./patches/heart/sounds-wdl.patch
patch.exe ./heart/weapon.wdl ./patches/heart/weapon-wdl.patch
patch.exe ./legalism/allobj.wdl ./patches/legalism/allobj-wdl.patch
patch.exe ./legalism/common.wdl ./patches/legalism/common-wdl.patch
patch.exe ./legalism/dead.wdl ./patches/legalism/dead-wdl.patch
patch.exe ./legalism/debug.wdl ./patches/legalism/debug-wdl.patch
patch.exe ./legalism/doors.wdl ./patches/legalism/doors-wdl.patch
patch.exe ./legalism/enemies2.wdl ./patches/legalism/enemies2-wdl.patch
patch.exe ./legalism/globals.wdl ./patches/legalism/globals-wdl.patch
patch.exe ./legalism/legalsnd.wdl ./patches/legalism/legalsnd-wdl.patch
patch.exe ./legalism/menu.wdl ./patches/legalism/menu-wdl.patch
patch.exe ./legalism/move.wdl ./patches/legalism/move-wdl.patch
patch.exe ./legalism/objects.wdl ./patches/legalism/objects-wdl.patch
patch.exe ./legalism/prayer.wdl ./patches/legalism/prayer-wdl.patch
patch.exe ./legalism/scroll.wdl ./patches/legalism/scroll-wdl.patch
patch.exe ./legalism/sounds.wdl ./patches/legalism/sounds-wdl.patch
patch.exe ./legalism/weapon.wdl ./patches/legalism/weapon-wdl.patch
patch.exe ./newage/allobj.wdl ./patches/newage/allobj-wdl.patch
patch.exe ./newage/common.wdl ./patches/newage/common-wdl.patch
patch.exe ./newage/dead.wdl ./patches/newage/dead-wdl.patch
patch.exe ./newage/debug.wdl ./patches/newage/debug-wdl.patch
patch.exe ./newage/doors.wdl ./patches/newage/doors-wdl.patch
patch.exe ./newage/enemies3.wdl ./patches/newage/enemies3-wdl.patch
patch.exe ./newage/globals.wdl ./patches/newage/globals-wdl.patch
patch.exe ./newage/menu.wdl ./patches/newage/menu-wdl.patch
patch.exe ./newage/move.wdl ./patches/newage/move-wdl.patch
patch.exe ./newage/nwagesnd.wdl ./patches/newage/nwagesnd-wdl.patch
patch.exe ./newage/objects.wdl ./patches/newage/objects-wdl.patch
patch.exe ./newage/prayer.wdl ./patches/newage/prayer-wdl.patch
patch.exe ./newage/scroll.wdl ./patches/newage/scroll-wdl.patch
patch.exe ./newage/sounds.wdl ./patches/newage/sounds-wdl.patch
patch.exe ./newage/weapon.wdl ./patches/newage/weapon-wdl.patch
patch.exe ./title/common.wdl ./patches/title/common-wdl.patch
patch.exe ./title/debug.wdl ./patches/title/debug-wdl.patch
patch.exe ./title/globals.wdl ./patches/title/globals-wdl.patch
patch.exe ./title/menu.wdl ./patches/title/menu-wdl.patch
patch.exe ./title/move.wdl ./patches/title/move-wdl.patch
patch.exe ./title/sounds.wdl ./patches/title/sounds-wdl.patch

REM Copy main scripts and geometry to project root
copy apathy\APATHY.WDL
copy legalism\LEGALISM.WDL
copy newage\NEWAGE.WDL
copy heart\HEART.WDL
copy title\TITLE.WDL
copy apathy\apathy.WMP
copy legalism\legalism.WMP
copy newage\newage.WMP
copy heart\heart.WMP
copy title\title.WMP
copy RETAIL\Vrun.exe

